@@ -1,14 +1,26 @@
 
 #' @title Search Author Content on SCOPUS
 #'
-#' @description Searches SCOPUS to get information about documents on an author.
+#' @description Searches SCOPUS to get information about documents
+#' on an author.
+#' Note, \code{author_list} returns a list of the entries from
+#' \code{author_search},
+#' but allows you to put in a name.
 #' @param au_id Author ID number. Overrides any first/last name argument
 #' @param last_name last name of author
 #' @param api_key Elsevier API key
 #' @param first_name first name of author
 #' @param verbose Print diagnostic messages
-#' @param all_author_info Should all author info be recorded instead of that just to the
+#' @param all_author_info Should all author info be recorded instead of
+#' that just to the
 #' author given
+#' @param http Address for scopus api
+#' @param view type of view to give, see
+#' \url{https://api.elsevier.com/documentation/ScopusSearchAPI.wadl}
+#' @param count number of records to retrieve (below 25, see
+#' \url{https://dev.elsevier.com/api_key_settings.html})
+#' @param general Should \code{\link{gen_entries_to_df}} instead of the
+#' way before version 0.5.10.9001
 #' @param ... Arguments to be passed to \code{\link{author_search}}
 #' @export
 #' @seealso \code{\link{get_author_info}}
@@ -16,14 +28,20 @@
 #' @examples \dontrun{
 #' author_df(last_name = "Muschelli", first_name = "John", verbose = FALSE)
 #' }
-#' @note The \code{author_data} command will return the list of all entries as well as
+#' @note The \code{author_data} command will return the list of all
+#' entries as well as
 #' the \code{data.frame}.
-author_df = function(au_id, last_name,
-                     first_name,
-                     api_key = NULL,
-                     verbose = TRUE,
-                     all_author_info = FALSE,
-                     ...){
+author_df = function(
+  au_id, last_name,
+  first_name,
+  api_key = NULL,
+  verbose = TRUE,
+  all_author_info = FALSE,
+  http = "https://api.elsevier.com/content/search/scopus",
+  view = "COMPLETE",
+  count = 25,
+  general = TRUE,
+  ...){
 
   L = author_data(au_id = au_id,
                   last_name = last_name,
@@ -31,6 +49,10 @@ author_df = function(au_id, last_name,
                   api_key = api_key,
                   verbose = verbose,
                   all_author_info = all_author_info,
+                  http = http,
+                  view = view,
+                  count = count,
+                  general = general,
                   ... = ...)
   df = L$df
 
@@ -38,15 +60,21 @@ author_df = function(au_id, last_name,
 }
 
 
-
+#' @rdname author_df
+#' @export
+author_df_orig = function(..., general = FALSE) {
+  author_df(..., general = general)
+}
 
 #' @rdname author_df
 #' @export
-author_data = function(au_id, last_name,
+author_list = function(au_id, last_name,
                        first_name,
                        api_key = NULL,
                        verbose = TRUE,
-                       all_author_info = FALSE,
+                       http = "https://api.elsevier.com/content/search/scopus",
+                       view = "COMPLETE",
+                       count = 25,
                        ...){
 
   api_key = get_api_key(api_key)
@@ -65,24 +93,52 @@ author_data = function(au_id, last_name,
   entries = author_search(au_id = au_id,
                           api_key = api_key,
                           verbose = verbose,
-                          ...)$entries
+                          view = view,
+                          http = http,
+                          count = count,
+                          ...)
+  entries$au_id = au_id
+  entries$first_name = first_name
+  entries$last_name = last_name
+
+  return(entries)
+}
 
 
+#' @rdname author_df
+#' @export
+author_data = function(...,
+                       verbose = TRUE,
+                       all_author_info = FALSE,
+                       general = TRUE){
 
-  if ( all_author_info ) {
-    # df$indexer = seq(nrow(df))
-    df = entries_to_df(entries = entries,
-                       au_id = NULL,
-                       verbose = verbose)
-    # df = merge(df, df2, sort = FALSE, all.x = TRUE)
-    # df = df[ order(df$indexer), ]
-    # df$indexer = NULL
+  entries = author_list(..., verbose = verbose)
+  au_id = entries$au_id
+  first_name = entries$first_name
+  last_name = entries$last_name
+  entries = entries$entries
+
+
+  if (general) {
+    xdf = gen_entries_to_df(entries)
+    df = xdf$df
   } else {
-    df = entries_to_df(entries = entries,
-                       au_id = au_id,
-                       verbose = verbose)
-  }
+    if ( all_author_info ) {
+      # df$indexer = seq(nrow(df))
+      df = entries_to_df(entries = entries,
+                         au_id = NULL,
+                         verbose = verbose)
+      # df = merge(df, df2, sort = FALSE, all.x = TRUE)
+      # df = df[ order(df$indexer), ]
+      # df$indexer = NULL
+    } else {
+      df = entries_to_df(entries = entries,
+                         au_id = au_id,
+                         verbose = verbose)
 
+    }
+    xdf = NULL
+  }
 
 
   # df$n_affiliations = n_affils
@@ -91,6 +147,7 @@ author_data = function(au_id, last_name,
   df$au_id = au_id
   L = list(entries = entries,
            df = df)
+  L$full_data = xdf
 
   return(L)
 }
@@ -103,13 +160,14 @@ author_data = function(au_id, last_name,
 #' @param au_id Author ID number. Overrides any first/last name argument
 #' @param last_name last name of author
 #' @param first_name first name of author
-  #' @param api_key Elsevier API key
+#' @param api_key Elsevier API key
 #' @param verbose Print diagnostic messages
 #' @return List of first/last name and author ID
 #' @note This function is really to avoid duplication
 #' @export
-process_author_name = function(au_id, last_name,
-                               first_name, api_key = NULL, verbose = TRUE) {
+process_author_name = function(
+  au_id, last_name,
+  first_name, api_key = NULL, verbose = TRUE) {
   # Getting AU-ID
   if (
     (!missing(last_name) | !missing(first_name) ) &
@@ -123,17 +181,17 @@ process_author_name = function(au_id, last_name,
       last_name = last_name,
       first_name = first_name,
       api_key = api_key, verbose = verbose)
-if (NROW(auth_name) == 0) {
-  stop("No author name found")
-}
-if (all(is.na(auth_name$au_id))) {
-  stop("No author name found")
-}
-if (verbose) {
-  message("Authors found:")
-  print(auth_name[1,])
-}
-au_id = auth_name$au_id[1]
+    if (NROW(auth_name) == 0) {
+      stop("No author name found")
+    }
+    if (all(is.na(auth_name$au_id))) {
+      stop("No author name found")
+    }
+    if (verbose) {
+      message("Authors found:")
+      print(auth_name[1,])
+    }
+    au_id = auth_name$au_id[1]
   }
   if (missing(last_name)) {
     last_name = NULL
@@ -146,4 +204,4 @@ au_id = auth_name$au_id[1]
            last_name = last_name,
            au_id = au_id)
   return(L)
-}
\ No newline at end of file
+}
