@@ -12,13 +12,15 @@ test_that("author_df_works", {
 
   if (have_api_key()) {
     expect_pass({
-        dd = author_df(au_id = "8858259000", all_author_info = TRUE)
+        dd = author_df(au_id = "8858259000", all_author_info = TRUE,
+                       count = 25)
     })
   }
 
   if (have_api_key()) {
     expect_pass({
-      dd = author_df(au_id = "8858259000", all_author_info = FALSE)
+      dd = author_df(au_id = "8858259000", all_author_info = FALSE,
+                     count = 25)
     })
   }
 })
